@@ -3,7 +3,7 @@ from .__errors__ import CommitError as __CErr
 from github import Github as __G
 from itertools import permutations as __perm
 from json import load as __load, dumps as __dumps
-from os import remove as __rem
+from os import remove as __rem, mkdir as __md
 from os.path import abspath as __abs, exists as __exs
 from pathlib import Path as __p
 from random import shuffle as __shuf
@@ -225,7 +225,10 @@ def __isNotFilled(grid):
 				yield (i, j)
 
 def log(value=None, showpath=False):
-	filename = f"{__p.home()}/Tic Tac Toe {__dt.today()}.log"
+	if not __exs(f"{__p.home()}/Python TicTacToe3 Logs"):
+		__md(f"{__p.home()}/Python TicTacToe3 Logs")
+
+	filename = f"{__p.home()}/Python TicTacToe3 Logs/Tic Tac Toe {__dt.today()}.log"
 
 	if showpath:
 		return __abs(filename)
